# Copyright (c) 2009 Entertainer Developers - See COPYING - GPLv2
'''FeedEntry - Screen displays one entry of some RSS feed'''

import pango

from entertainerlib.gui.screens.screen import Screen
from entertainerlib.gui.user_event import UserEvent
from entertainerlib.gui.widgets.label import Label
from entertainerlib.gui.widgets.scroll_area import ScrollArea
from entertainerlib.gui.widgets.texture import Texture
from entertainerlib.backend.components.feeds.feed_utils import FeedEntryParser

class FeedEntry(Screen):
    '''Screen displays one feed entry.'''

    def __init__(self, feed, entry):
        Screen.__init__(self, 'FeedEntry')

        self.theme = self.config.theme
        self.feed = feed
        self.entry = entry

        # Screen Title (Displayed at the bottom left corner)
        screen_title_text = FeedEntryParser().convert(self.feed.title)
        screen_title = Label(0.13, "screentitle", 0, 0.87, screen_title_text)
        screen_title.set_ellipsize(pango.ELLIPSIZE_END)
        screen_title.width = 0.8
        screen_title.set_use_markup(True)
        self.add(screen_title)

        # RSS Icon
        icon = Texture(self.theme.getImage("rss_icon"), 0.05, 0.07)
        self.add(icon)

        # Entry Title
        title_text = FeedEntryParser().convert(self.feed.title)
        title = Label(0.065, "title", 0.13, 0.07, title_text)
        title.set_use_markup(True)
        title.width = 0.6
        title.set_ellipsize(pango.ELLIPSIZE_END)
        self.add(title)

        # RSS Feed descrption
        full_text = self.entry.title
        try:
            sub_title = full_text[:full_text.index('\n')]
        except ValueError:
            sub_title = full_text
        desc_text = FeedEntryParser().convert(sub_title)
        desc = Label(0.0365, "subtitle", 0.13, 0.14, desc_text)
        desc.set_use_markup(True)
        desc.set_ellipsize(pango.ELLIPSIZE_END)
        desc.width = 0.6
        self.add(desc)

        # Last update
        update = Label(0.0313, "title", 0.78, 0.1, _("Updated"))
        self.add(update)
        date_text = self.entry.time[:5]  + " - " +  self.entry.date
        date = Label(0.0313, "subtitle", 0.78, 0.14, date_text)
        self.add(date)

        # Entry descrption
        if len(self.entry.description.strip()) == 0:
            entry_text = Label(0.04167, "text", 0.35, 0.48,
                _("Entry has no content"))
            self.add(entry_text)
        else:
            entry_text_data = FeedEntryParser().convert(self.entry.description)
            entry_text = Label(0.0365, "text", 0, 0, entry_text_data)
            entry_text.set_use_markup(True)
            entry_text.set_size(0.5857, 0.5208)

            self.scroll_area = ScrollArea(0.2072, 0.3, 0.5857, 0.4948,
                entry_text)
            self.add(self.scroll_area)

        # Add the additional actions that are needed but not handled by default
        self.event_handlers.update({
            UserEvent.NAVIGATE_FIRST_PAGE : self._handle_first_page,
            UserEvent.NAVIGATE_LAST_PAGE : self._handle_last_page,
            UserEvent.NAVIGATE_PREVIOUS_PAGE : self._handle_previous_page,
            UserEvent.NAVIGATE_NEXT_PAGE : self._handle_next_page
        })

        # We're at the end without any problems so lets set the entry as read.
        self.entry.read = True

    def _handle_up(self):
        '''Handle UserEvent.NAVIGATE_UP.'''
        self.scroll_area.scroll_up()

    def _handle_down(self):
        '''Handle UserEvent.NAVIGATE_DOWN.'''
        self.scroll_area.scroll_down()

    def _handle_first_page(self):
        '''Handle UserEvent.NAVIGATE_FIRST_PAGE.'''
        self.scroll_area.scroll_to_top()

    def _handle_last_page(self):
        '''Handle UserEvent.NAVIGATE_LAST_PAGE.'''
        self.scroll_area.scroll_to_bottom()

    def _handle_previous_page(self):
        '''Handle UserEvent.NAVIGATE_PREVIOUS_PAGE.'''
        self.scroll_area.scroll_page_up()

    def _handle_next_page(self):
        '''Handle UserEvent.NAVIGATE_NEXT_PAGE.'''
        self.scroll_area.scroll_page_down()

