# Copyright (c) 2009 Entertainer Developers - See COPYING - GPLv2
'''Simple selector texture to show current position in menu'''

import clutter

from entertainerlib.gui.widgets.texture import Texture

class Selector(clutter.Group):
    """
    Simple selector widget.

    Selector is an animated texture that can be used to display current
    position in menus.
    """

    # Selector size constants (One of these should be given when initializing)
    SMALL = 0
    LARGE = 1

    def __init__(self, theme):
        """
        Initialize Selector widget and start animation.
        @param size: Size of the selector. Use class constants SMALL and LARGE
        @param theme: Theme object
        """
        clutter.Group.__init__(self)
        self.animate_selector = False

        selector_filename = theme.getImage("selector")
        glow_filename = theme.getImage("selector_glow")

        # Set selector base texture
        self.selector = Texture(selector_filename)
        self.selector.set_opacity(200)
        self.add(self.selector)

        # Set selector GLOW texture
        self.glow = Texture(glow_filename)
        self.glow.set_opacity(0)
        self.add(self.glow)

        # Animate selector (Glow effect with glow overlay texture)
        self.timeline = clutter.Timeline(150)
        self.timeline.set_loop(True)
        self.alpha = clutter.Alpha(self.timeline, clutter.EASE_IN_SINE)
        self.behaviour = clutter.BehaviourOpacity(0, 255, self.alpha)
        self.behaviour.apply(self.glow)

    def set_size(self, width, height):
        """Overrides clutter.Actor.set_size()"""
        self.selector.set_size(width, height)
        self.glow.set_size(width, height)

    def stop_animation(self):
        """Stop selector animation"""
        self.timeline.stop()
        self.glow.set_opacity(0)

    def start_animation(self):
        """Start selector animation"""
        self.timeline.start()

    def hide(self):
        """Overrides clutter.Actor.hide()"""
        clutter.Group.hide(self)
        if self.animate_selector:
            self.stop_animation()

    def show(self):
        """Overrides clutter.Actor.show()"""
        clutter.Group.show(self)
        self.start_animation()

    def hide_all(self):
        """Overrides clutter.Actor.hide_all()"""
        clutter.Group.hide_all(self)
        self.stop_animation()

    def show_all(self):
        """Overrides clutter.Actor.show_all()"""
        clutter.Group.show_all(self)
        self.start_animation()

